@@ -37,7 +37,6 @@
 #include <queue>
 #include <fstream>
 #include <miopen/miopen.h>
-#include <miopen/solver.hpp>
 #include <nlohmann/json.hpp>
 #include <miopen/db_path.hpp>
 #include <miopen/any_solver.hpp>
@@ -64,15 +63,17 @@ public:
     const std::unordered_map<size_t, std::string> solver_map;
     const std::vector<float> features_mean;
     const std::vector<float> features_std;
+    const std::vector<float> test_features_mean;
+    const std::vector<float> test_features_std;
     Metadata(const std::string& arch);
     size_t EncodeDirection(miopen::conv::Direction dir) const;
     size_t EncodePrecision(miopenDataType_t data_type) const;
     size_t EncodeLayout(const std::string& layout) const;
 };
 class Model;
-std::vector<uint64_t> PredictSolver(const conv::ProblemDescription& problem,
-                                    const ExecutionContext& ctx,
-                                    const std::string& device);
+MIOPEN_INTERNALS_EXPORT std::vector<uint64_t> PredictSolver(const conv::ProblemDescription& problem,
+                                                            const ExecutionContext& ctx,
+                                                            const std::string& device);
 } // namespace immed_mode
 
 #endif // MIOPEN_ENABLE_AI_IMMED_MODE_FALLBACK
@@ -80,13 +81,15 @@ std::vector<uint64_t> PredictSolver(const conv::ProblemDescription& problem,
 namespace tuning {
 struct Metadata
 {
-    std::size_t num_tuning_params;
+    std::size_t predict_type;
+    std::unordered_map<std::string, std::size_t> num_tuning_params;
     std::unordered_map<std::string, std::string> tuning_decodings;
     Metadata(const std::string& arch, const std::string& solver);
 };
 
 bool ModelSetParams(const std::string& arch,
                     const std::string& solver,
+                    conv::Direction direction,
                     const std::vector<float>& features,
                     bool transform_features,
                     std::function<bool(std::size_t, std::string)> validator);
