@@ -63,7 +63,6 @@
 namespace fs  = miopen::fs;
 namespace env = miopen::env;
 
-MIOPEN_DECLARE_ENV_VAR_BOOL(MIOPEN_TEST_DBSYNC)
 MIOPEN_DECLARE_ENV_VAR_BOOL(MIOPEN_DBSYNC_CLEAN)
 
 struct KDBKey
@@ -339,6 +338,7 @@ void GetPerfDbVals(const fs::path& filename,
                    std::unordered_map<std::string, std::string>& vals,
                    std::string& select_query)
 {
+#if MIOPEN_ENABLE_SQLITE && MIOPEN_USE_SQLITE_PERFDB
     std::string clause;
     std::vector<std::string> values;
     std::tie(clause, values) = problem_config.WhereClause();
@@ -363,6 +363,35 @@ void GetPerfDbVals(const fs::path& filename,
         else if(rc == SQLITE_ERROR || rc == SQLITE_MISUSE)
             throw std::runtime_error(sql.ErrorMessage());
     }
+#else
+    const auto& perf_db =
+        miopen::ReadonlyRamDb::GetCached(miopen::DbKinds::PerfDb, filename.string(), true);
+    const auto& perf_db_map = perf_db.GetCacheMap();
+
+    std::ostringstream ss;
+    conv::ProblemDescription::VisitAll(problem_config, [&](auto&& value, auto&&) {
+        if(ss.tellp() != 0)
+            ss << "x";
+        ss << value;
+    });
+    const auto key = ss.str();
+
+    if(perf_db_map.find(key) != perf_db_map.end())
+    {
+        std::istringstream pdb_line{perf_db_map.at(key).content};
+        char fragment[1024];
+        while(pdb_line.getline(fragment, 1024, ';'))
+        {
+            std::string id_val{fragment};
+            const auto id_size = id_val.find(':');
+            ASSERT_TRUE(id_size != std::string::npos) << "Ill formed value: " << id_val;
+            auto id  = id_val.substr(0, id_size);
+            auto cfg = id_val.substr(id_size + 1);
+            vals.emplace(id, cfg);
+        }
+        select_query = " Loading " + key + " from " + filename.string();
+    }
+#endif
 }
 
 void RemovePerfDbEntry(const fs::path& filename,
@@ -484,8 +513,12 @@ void SetupPaths(fs::path& fdb_file_path,
     const std::string base_name = handle.GetDbBasename(); // "gfx90a68";
     const std::string suffix    = "HIP";                  // miopen::GetSystemFindDbSuffix();
     fdb_file_path               = root_path / (base_name + "." + suffix + ext);
-    pdb_file_path               = root_path / (base_name + ".db");
-    kdb_file_path               = root_path / (handle.GetDeviceName() + ".kdb");
+#if MIOPEN_ENABLE_SQLITE && MIOPEN_USE_SQLITE_PERFDB
+    pdb_file_path = root_path / (base_name + ".db");
+#else
+    pdb_file_path = root_path / (base_name + ".db.txt");
+#endif
+    kdb_file_path = root_path / (handle.GetDeviceName() + ".kdb");
     ASSERT_TRUE(fs::exists(fdb_file_path)) << "Db file does not exist" << fdb_file_path;
     ASSERT_TRUE(fs::exists(pdb_file_path)) << "Db file does not exist" << pdb_file_path;
     ASSERT_TRUE(SKIP_KDB_PDB_TESTING || fs::exists(kdb_file_path))
@@ -494,22 +527,15 @@ void SetupPaths(fs::path& fdb_file_path,
 
 TEST(CPU_DBSync_NONE, KDBTargetID)
 {
-    if(env::enabled(MIOPEN_TEST_DBSYNC))
-    {
-        fs::path fdb_file_path, pdb_file_path, kdb_file_path;
+    fs::path fdb_file_path, pdb_file_path, kdb_file_path;
 #if WORKAROUND_ISSUE_2492
-        SetEnvironmentVariable("MIOPEN_DEBUG_WORKAROUND_ISSUE_2492", "0");
+    SetEnvironmentVariable("MIOPEN_DEBUG_WORKAROUND_ISSUE_2492", "0");
 #endif
-        SetupPaths(fdb_file_path, pdb_file_path, kdb_file_path, get_handle());
-        std::ignore = fdb_file_path;
-        std::ignore = pdb_file_path;
-        EXPECT_TRUE(miopen::CheckKDBJournalMode(kdb_file_path));
-        EXPECT_FALSE(!SKIP_KDB_PDB_TESTING && miopen::CheckKDBForTargetID(kdb_file_path));
-    }
-    else
-    {
-        GTEST_SKIP();
-    }
+    SetupPaths(fdb_file_path, pdb_file_path, kdb_file_path, get_handle());
+    std::ignore = fdb_file_path;
+    std::ignore = pdb_file_path;
+    EXPECT_TRUE(miopen::CheckKDBJournalMode(kdb_file_path));
+    EXPECT_FALSE(!SKIP_KDB_PDB_TESTING && miopen::CheckKDBForTargetID(kdb_file_path));
 }
 
 bool LogBuildMessage()
@@ -520,7 +546,7 @@ bool LogBuildMessage()
 
 void BuildKernel(const fs::path& program_file,
                  const std::string& program_args,
-                 [[maybe_unused]] miopen::Handle& handle)
+                 [[maybe_unused]] const miopen::Handle& handle)
 {
     // Build the code object entry
     // This will write the code object in the user kdb which Jenkins can archive
@@ -687,10 +713,12 @@ void CheckFDBEntry(size_t thread_index,
             << "Failed to parse FDB key:" << kidx << ":Parsed Key: " << ss.str();
 
         std::vector<miopen::FDBVal> fdb_vals;
-        std::unordered_map<std::string, std::string> pdb_vals;
         miopen::ParseFDBbVal(kinder.second.content, fdb_vals);
+
+        std::unordered_map<std::string, std::string> pdb_vals;
         std::string pdb_select_query;
         miopen::GetPerfDbVals(pdb_file_path, problem, pdb_vals, pdb_select_query);
+
         // This is an opportunity to link up fdb and pdb entries
         auto fdb_idx = 0; // check kdb only for the fastest kernel
         for(const auto& val : fdb_vals)
@@ -726,10 +754,12 @@ void CheckFDBEntry(size_t thread_index,
                 << "Solver is not applicable fdb-key:" << kinder.first
                 << " Solver: " << id.ToString();
             miopen::solver::ConvSolution sol;
+
+            auto db                     = miopen::GetDb(ctx);
+            const auto pdb_entry_exists = pdb_vals.find(val.solver_id) != pdb_vals.end();
+
             if(solv.IsTunable())
             {
-                const auto pdb_entry_exists = pdb_vals.find(val.solver_id) != pdb_vals.end();
-                // TODO: Print the SQL query
                 if(env::enabled(MIOPEN_DBSYNC_CLEAN) && not pdb_entry_exists)
                 {
                     MIOPEN_LOG_W("PDB entry does not exist for tunable fdb-key:"
@@ -747,19 +777,18 @@ void CheckFDBEntry(size_t thread_index,
                         << "PDB entry does not exist for tunable fdb-key:" << kinder.first
                         << ": solver" << val.solver_id << " pdb-select-query: " << pdb_select_query;
                 }
-                auto db               = miopen::GetDb(ctx);
-                std::string pdb_entry = "";
+                std::string perf_cfg = "";
                 if(!SKIP_KDB_PDB_TESTING && pdb_entry_exists)
                 {
-                    pdb_entry = pdb_vals.at(val.solver_id);
-                    bool res  = solv.TestPerfCfgParams(ctx, problem, pdb_vals.at(val.solver_id));
+                    perf_cfg = pdb_vals.at(val.solver_id);
+                    bool res = solv.TestPerfCfgParams(ctx, problem, perf_cfg);
                     if(env::enabled(MIOPEN_DBSYNC_CLEAN) && not res)
                     {
                         MIOPEN_LOG_W("Invalid perf config found fdb-key:"
-                                     << kinder.first << ": solver" << val.solver_id
-                                     << ", Removing entry from fdb and pdb");
+                                     << kinder.first << ", Solver" << val.solver_id << ":"
+                                     << perf_cfg << ", Removing entry from fdb and pdb");
                         find_db_rw.Remove(kinder.first, id.ToString());
-                        RemovePerfDbEntry(pdb_file_path, problem, id.ToString());
+                        db.Remove(problem, id.ToString());
                         MIOPEN_LOG_W("Removal Complete fdb-key:" << kinder.first << ": solver"
                                                                  << val.solver_id);
                         continue;
@@ -768,25 +797,24 @@ void CheckFDBEntry(size_t thread_index,
                     {
                         EXPECT_TRUE(res) << '[' << (++failures) << "] " //
                                          << "Invalid perf config found fdb-key:" << kinder.first
-                                         << " Solver: " << solv.GetSolverDbId() << ":"
-                                         << pdb_vals.at(val.solver_id)
+                                         << ", Solver: " << val.solver_id << ":" << perf_cfg
                                          << " pdb-select-query: " << pdb_select_query;
                     }
                     // we can verify the pdb entry by passing in an empty string and then comparing
                     // the received solution with the one below or having the find_solution pass out
                     // the serialized string
-                    sol = solv.FindSolution(ctx, problem, db, {}, pdb_vals.at(val.solver_id));
+                    sol = solv.FindSolution(ctx, problem, db, {}, perf_cfg);
                 }
                 else
                 {
-                    sol       = solv.FindSolution(ctx, problem, db, {}, "");
-                    pdb_entry = " Not Found (Using Default)";
+                    sol      = solv.FindSolution(ctx, problem, db, {}, "");
+                    perf_cfg = " Not Found (Using Default)";
                 }
                 // TODO Generate the Select query for pdb
                 EXPECT_TRUE(sol.Succeeded())
                     << '[' << (++failures) << "] " //
                     << "Invalid solution fdb-key:" << kinder.first << " Solver: " << id.ToString()
-                    << " pdb-val:" << pdb_entry;
+                    << " perf config:" << perf_cfg;
                 if(!SKIP_KDB_PDB_TESTING && fdb_idx == 0)
                 {
                     for(const auto& kern : sol.construction_params)
@@ -814,7 +842,7 @@ void CheckFDBEntry(size_t thread_index,
                             EXPECT_TRUE(found)
                                 << '[' << (++failures) << "] " //
                                 << "KDB entry not found for  fdb-key:" << kinder.first
-                                << " Solver: " << id.ToString() << " pdb-val:" << pdb_entry
+                                << ", Solver: " << id.ToString() << " perf config:" << perf_cfg
                                 << " filename: " << program_file << " compile args: "
                                 << compile_options; // for fdb key, solver id, solver pdb entry and
                                                     // kdb file and args
@@ -824,7 +852,7 @@ void CheckFDBEntry(size_t thread_index,
                 }
             }
             else
-                EXPECT_TRUE(pdb_vals.find(val.solver_id) == pdb_vals.end())
+                EXPECT_TRUE(!pdb_entry_exists)
                     << '[' << (++failures) << "] " //
                     << "Non-Tunable solver found in PDB" << solv.GetSolverDbId();
             ++fdb_idx;
@@ -892,14 +920,16 @@ void StaticFDBSync(const std::string& arch, const size_t num_cu)
         miopen::RamDb::GetCached(miopen::DbKinds::FindDb, fdb_file_path.string(), false);
     // assert that find_db.cache is not empty, since that indicates the file was not readable
     ASSERT_TRUE(!find_db.GetCacheMap().empty()) << "Find DB does not have any entries";
-    auto _ctx = miopen::ExecutionContext{};
-    _ctx.SetStream(&handle);
 
     // Convert the map to a vector
     std::vector<FDBLine> fdb_data;
     const auto& find_db_map = find_db.GetCacheMap();
     fdb_data.resize(find_db_map.size());
     std::copy(find_db_map.begin(), find_db_map.end(), fdb_data.begin());
+
+    auto _ctx = miopen::ExecutionContext{};
+    _ctx.SetStream(&handle);
+
     std::atomic<size_t> counter = 0;
     const int total_threads =
         std::min(std::thread::hardware_concurrency(), static_cast<unsigned int>(32));
@@ -927,17 +957,10 @@ struct CPU_DBSync_NONE : testing::TestWithParam<std::pair<std::string, size_t>>
 
 TEST_P(CPU_DBSync_NONE, StaticFDBSync)
 {
-    if(env::enabled(MIOPEN_TEST_DBSYNC))
-    {
-        std::string arch;
-        size_t num_cu;
-        std::tie(arch, num_cu) = GetParam();
-        StaticFDBSync(arch, num_cu);
-    }
-    else
-    {
-        GTEST_SKIP();
-    }
+    std::string arch;
+    size_t num_cu;
+    std::tie(arch, num_cu) = GetParam();
+    StaticFDBSync(arch, num_cu);
 }
 
 INSTANTIATE_TEST_SUITE_P(Smoke,
