@@ -68,15 +68,15 @@ bool IsTestSupportedForDevice()
 
 } // namespace
 
-class GPU_Conv2dDefault_FP32 : public FloatTestCase<std::vector<TestCase>>
+class GPU_Conv2dDefaultAsm_5x10_7x7_FP32 : public FloatTestCase<std::vector<TestCase>>
 {
 };
 
-TEST_P(GPU_Conv2dDefault_FP32, FloatTest_smoke_solver_ConvAsm_5x10_7x7)
+TEST_P(GPU_Conv2dDefaultAsm_5x10_7x7_FP32, FloatTest_smoke_solver_ConvAsm_5x10_7x7)
 {
     if(IsTestSupportedForDevice() && !SkipTest())
     {
-        invoke_with_params<conv2d_driver, GPU_Conv2dDefault_FP32>(default_check);
+        invoke_with_params<conv2d_driver, GPU_Conv2dDefaultAsm_5x10_7x7_FP32>(default_check);
     }
     else
     {
@@ -84,4 +84,6 @@ TEST_P(GPU_Conv2dDefault_FP32, FloatTest_smoke_solver_ConvAsm_5x10_7x7)
     }
 };
 
-INSTANTIATE_TEST_SUITE_P(Smoke, GPU_Conv2dDefault_FP32, testing::Values(GetTestCases()));
+INSTANTIATE_TEST_SUITE_P(Smoke,
+                         GPU_Conv2dDefaultAsm_5x10_7x7_FP32,
+                         testing::Values(GetTestCases()));
